@@ -7,13 +7,17 @@
 #ifndef KEXTHIGHSCORE_INTERNAL_H
 #define KEXTHIGHSCORE_INTERNAL_H
 
+#include "kexthighscore.h"
+
+#include <ki18n_version.h>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KHighscore>
-
-#include "kexthighscore.h"
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+#include <KLazyLocalizedString>
+#endif
 
 #include <QDateTime>
 #include <QTextStream>
@@ -92,7 +96,11 @@ class ItemContainer
     bool canHaveSubGroup() const { return !_subGroup.isNull(); }
 
     static const char ANONYMOUS[]; // name assigned to anonymous players
+#if KI18N_VERSION >= QT_VERSION_CHECK(5, 89, 0)
+    static const KLazyLocalizedString ANONYMOUS_LABEL;
+#else
     static const char ANONYMOUS_LABEL[];
+#endif
 
     QVariant read(uint i) const;
     QString pretty(uint i) const;
